@@ -197,7 +197,8 @@ class TaskDefs(dict):
 
             directory = str(path)
             if 'dir' in obj:
-                directory = self.run_vars['dir'].replace('$', '') + '/' + obj['dir']
+                post = obj['dir']
+                directory = directory + '/' + post.replace('$', '')
 
             if 'condition' in obj:
                 self.run_vars['condition'] = obj['condition'].replace('$', '')
@@ -376,9 +377,11 @@ class SequentialTaskList(TaskList):
 
                 for i, task in enumerate(self.tasks):
                     run_task = copy.copy(task)
-                    if isinstance(run_task, PythonTask):
-                        pprint(vars(run_task))
+#                    if isinstance(run_task, PythonTask):
+#                        pprint(vars(run_task))
                     if isinstance(run_task, Task):
+                        print(self.vars)
+                        pprint(vars(run_task))
                         run_task.cmd = run_task.cmd.format(**self.vars)
                     if self.kill:
                         break
